@@ -195,8 +195,8 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
             transforms.append(binary)
         return pd.concat(transforms, axis=1).mask(pd.isnull(X)).astype('O')
 
-class CategoricalTransformer(BaseEstimator, TransformerMixin):
-    """Converts categoricals to nominals and replaces missing and unknowns with nan."""
+class OrdinalEncoder(BaseEstimator, TransformerMixin):
+    """Converts categoricals to ordinals and replaces missing and unknowns with nan."""
     def fit(self, X, y = None):
         """
         Fits transformer to X.
